@@ -309,28 +309,8 @@ angular.module('syncthing.core')
             if (!$scope.completion[data.device]) {
                 $scope.completion[data.device] = {};
             }
-            $scope.completion[data.device][data.folder] = data.completion;
-
-            var tot = 0,
-                cnt = 0,
-                isComplete = true;
-            for (var cmp in $scope.completion[data.device]) {
-                if (cmp === "_total") {
-                    continue;
-                }
-                tot += $scope.completion[data.device][cmp] * $scope.model[cmp].globalBytes;
-                cnt += $scope.model[cmp].globalBytes;
-                if ($scope.completion[data.device][cmp] != 100) {
-                    isComplete = false;
-                }
-            }
-            //To be sure that we won't get any rounding errors resulting in non-100% status when it should be
-            if (isComplete) {
-                $scope.completion[data.device]._total = 100;
-            }
-            else {
-                $scope.completion[data.device]._total = tot / cnt;
-            }
+            $scope.completion[data.device][data.folder] = data;
+            recalcCompletion(data.device);
         });
 
         $scope.$on(Events.FOLDER_ERRORS, function (event, arg) {
@@ -458,6 +438,32 @@ angular.module('syncthing.core')
             }
         }
 
+        function recalcCompletion(device) {
+            var total = 0, needed = 0, deletes = 0;
+            for (var folder in $scope.completion[device]) {
+                if (folder === "_total") {
+                    continue;
+                }
+                total += $scope.completion[device][folder].globalBytes;
+                needed += $scope.completion[device][folder].needBytes;
+                deletes += $scope.completion[device][folder].needDeletes;
+            }
+            if (total == 0) {
+                $scope.completion[device]._total = 100;
+            } else {
+                $scope.completion[device]._total = 100 * (1 - needed / total);
+            }
+
+            if (needed == 0 && deletes > 0) {
+                // We don't need any data, but we have deletes that we need
+                // to do. Drop down the completion percentage to indicate
+                // that we have stuff to do.
+                $scope.completion[device]._total = 95;
+            }
+
+            console.log("recalcCompletion", device, $scope.completion[device]);
+        }
+
         function refreshCompletion(device, folder) {
             if (device === $scope.myID) {
                 return;
@@ -467,30 +473,8 @@ angular.module('syncthing.core')
                 if (!$scope.completion[device]) {
                     $scope.completion[device] = {};
                 }
-                $scope.completion[device][folder] = data.completion;
-
-                var tot = 0,
-                    cnt = 0,
-                    isComplete = true;
-                for (var cmp in $scope.completion[device]) {
-                    if (cmp === "_total") {
-                        continue;
-                    }
-                    tot += $scope.completion[device][cmp] * $scope.model[cmp].globalBytes;
-                    cnt += $scope.model[cmp].globalBytes;
-                    if ($scope.completion[device][cmp] != 100) {
-                        isComplete = false;
-                    }
-                }
-                //To be sure that we won't get any rounding errors resulting in non-100% status when it should be
-                if (isComplete) {
-                    $scope.completion[device]._total = 100;
-                }
-                else {
-                    $scope.completion[device]._total = tot / cnt;
-                }
-
-                console.log("refreshCompletion", device, folder, $scope.completion[device]);
+                $scope.completion[device][folder] = data;
+                recalcCompletion(device);
             }).error($scope.emitHTTPError);
         }
 
@@ -670,7 +654,7 @@ angular.module('syncthing.core')
             if (state === 'error') {
                 return 'stopped'; // legacy, the state is called "stopped" in the GUI
             }
-            if (state === 'idle' && $scope.model[folderCfg.id].needFiles > 0) {
+            if (state === 'idle' && $scope.model[folderCfg.id].needFiles + $scope.model[folderCfg.id].needDeletes > 0) {
                 return 'outofsync';
             }
             if (state === 'scanning') {
